@@ -18,7 +18,7 @@
  *
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: console.c,v 1.9 2005/01/04 23:28:03 joel Exp $
+ *  $Id$
  */
 
 #include <termios.h>
@@ -31,6 +31,7 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <rtems/termiostypes.h>
 
 #define CONSOLE_VECTOR 121
 #define CONSOLE_IRQ_LEVEL 3
@@ -170,8 +171,8 @@ InterruptHandler (rtems_vector_number v)
 	       may be called by either console_write
 	       or rtems_termios_enqueue_raw_characters
  *****************************************************/
-static int
-InterruptWrite (int minor, const char *buf, int len)
+static ssize_t
+InterruptWrite (int minor, const char *buf, size_t len)
 {
  if (minor==UART_CHANNEL_A) {
     if (len>0) DUTBA=*buf;
@@ -245,7 +246,7 @@ int dbug_char_present( int minor )
   Description: Init the UART
  *****************************************************/
 static void
-dbugInitialise ()
+dbugInitialise (void)
 {
      t_baud_speed_table uart_config;		/* configuration of UARTS */
 
@@ -295,8 +296,6 @@ dbugInitialise ()
 	   rtems_isr_entry old_handler;
 	   rtems_status_code sc;
 
-	   extern void _Debug_ISR_Handler_Console(void);
-
 	   sc = rtems_interrupt_catch (InterruptHandler,
 	  			       CONSOLE_VECTOR,
 				       &old_handler);
@@ -381,8 +380,6 @@ dbugInitialise ()
 	   rtems_isr_entry old_handler;
 	   rtems_status_code sc;
 
-	   extern void _Debug_ISR_Handler_Console(void);
-
 	   sc = rtems_interrupt_catch (InterruptHandler,
 	  			       CONSOLE_VECTOR,
 				       &old_handler);
@@ -486,8 +483,8 @@ SetAttributes (int minor, const struct termios *t)
  isp = (t->c_cflag / (CIBAUD / CBAUD)) &  CBAUD;
 
  /* convert it */
- ispeed = termios_baud_rates_equivalence(isp);
- ospeed = termios_baud_rates_equivalence(osp);
+ ispeed = rtems_termios_baud_to_number(isp);
+ ospeed = rtems_termios_baud_to_number(osp);
 
  if (ispeed || ospeed) {
        /* update config table */
@@ -553,7 +550,7 @@ rtems_device_driver console_initialize(
 	 */
         Init_UART_Table();
 	dbugInitialise ();
-	Fifo_Full_Timer_initialize();
+	Fifo_Full_benchmark_timer_initialize();
 
 	/*
 	 * Register the devices
