@@ -11,7 +11,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: console-io.c,v 1.5 2004/04/21 16:01:47 ralf Exp $
+ *  $Id$
  */
 
 #include <bsp.h>
@@ -19,11 +19,9 @@
 #include <stdlib.h>
 #include <assert.h>
 
-#define SYS_exit        1
-#define SYS_read        3
-#define SYS_write       4
+#include <syscall.h>
 
-int errno ;
+int errno;
 
 extern int __trap34(int, int, void*, int );
 
@@ -70,7 +68,7 @@ int console_inbyte_nonblocking(
 }
 
 /* XXX wrong place for this */
-_sys_exit (n)
+int _sys_exit (int n)
 {
   return __trap34 (SYS_exit, n, 0, 0);
 }
