@@ -1,7 +1,7 @@
 /*
  *  AMBA Plug & Play routines
  *
- *  COPYRIGHT (c) 2009.
+ *  COPYRIGHT (c) 2011.
  *  Aeroflex Gaisler.
  *
  *  The license and distribution terms for this file may be
@@ -26,31 +26,18 @@
 #define AMBA_AHB_SLAVE_CONF_AREA (1 << 11)
 #define AMBA_APB_SLAVES 16
 
-/* LEON3 BSP calls AMBA initialization before malloc() works,
- * but the BSP provides a early-malloc routine that can be used. On the
- * LEON2 BSP malloc() can be used since it is never called so early in
- * boot process.
- */
-#ifdef LEON3
-#define EARLY_MALLOC bsp_early_malloc
-#else
-#define EARLY_MALLOC malloc
-#endif
-
 /* Allocate one AMBA device */
 struct ambapp_dev *ambapp_alloc_dev_struct(int dev_type)
 {
 	int size = sizeof(struct ambapp_dev);
 	struct ambapp_dev *dev;
 
-	if ( dev_type == DEV_APB_SLV ) {
+	if (dev_type == DEV_APB_SLV)
 		size += sizeof(struct ambapp_apb_info);
-	} else {
-		/* AHB */
-		size += sizeof(struct ambapp_ahb_info);
-	}
-	dev = (struct ambapp_dev *)EARLY_MALLOC(size);
-	if ( dev == NULL )
+	else
+		size += sizeof(struct ambapp_ahb_info); /* AHB */
+	dev = (struct ambapp_dev *)bsp_early_malloc(size);
+	if (dev == NULL)
 		return NULL;
 	memset(dev, 0 , size);
 	dev->dev_type = dev_type;
@@ -60,18 +47,18 @@ struct ambapp_dev *ambapp_alloc_dev_struct(int dev_type)
 unsigned int
 ambapp_addr_from (struct ambapp_mmap *mmaps, unsigned int address)
 {
-  /* no translation? */
-  if (!mmaps)
-    return address;
+	/* no translation? */
+	if (!mmaps)
+		return address;
 
-  while (mmaps->size) {
-    if ((address >= mmaps->remote_adr)
-        && (address <= (mmaps->remote_adr + (mmaps->size - 1)))) {
-      return (address - mmaps->remote_adr) + mmaps->local_adr;
-    }
-    mmaps++;
-  }
-  return 1;
+	while (mmaps->size) {
+		if ((address >= mmaps->remote_adr) &&
+		    (address <= (mmaps->remote_adr + (mmaps->size - 1)))) {
+			return (address - mmaps->remote_adr) + mmaps->local_adr;
+		}
+		mmaps++;
+	}
+	return 1;
 }
 
 void ambapp_ahb_dev_init(
@@ -89,7 +76,7 @@ void ambapp_ahb_dev_init(
 	/* Setup device struct */
 	dev->vendor = ambapp_pnp_vendor(ahb->id);
 	dev->device = ambapp_pnp_device(ahb->id);
-	ahb_info = (struct ambapp_ahb_info *)dev->devinfo;
+	ahb_info = DEV_TO_AHB(dev);
 	ahb_info->ver = ambapp_pnp_ver(ahb->id);
 	ahb_info->irq = ambapp_pnp_irq(ahb->id);
 	ahb_info->ahbidx = ahbidx;
@@ -100,12 +87,12 @@ void ambapp_ahb_dev_init(
 	/* Memory BARs */
 	for (bar=0; bar<4; bar++) {
 		mbar = ahb->mbar[bar];
-		if ( mbar == 0 ) {
+		if (mbar == 0) {
 			addr = 0;
 			mask = 0;
 		} else {
 			addr = ambapp_pnp_start(mbar);
-			if ( ambapp_pnp_mbar_type(mbar) == AMBA_TYPE_AHBIO ) {
+			if (ambapp_pnp_mbar_type(mbar) == AMBA_TYPE_AHBIO) {
 				/* AHB I/O area is releative IO_AREA */
 				addr = AMBA_TYPE_AHBIO_ADDR(addr, ioarea);
 				mask = (((unsigned int)
@@ -137,7 +124,7 @@ void ambapp_apb_dev_init(
 	/* Setup device struct */
 	dev->vendor = ambapp_pnp_vendor(apb->id);
 	dev->device = ambapp_pnp_device(apb->id);
-	apb_info = (struct ambapp_apb_info *)dev->devinfo;
+	apb_info = DEV_TO_APB(dev);
 	apb_info->ver = ambapp_pnp_ver(apb->id);
 	apb_info->irq = ambapp_pnp_irq(apb->id);
 	apb_info->ahbidx = ahbidx;
@@ -152,10 +139,10 @@ int ambapp_add_ahbbus(
 {
 	int i;
 	for (i=0; i<AHB_BUS_MAX; i++) {
-		if ( abus->ahbs[i].ioarea == 0 ) {
+		if (abus->ahbs[i].ioarea == 0) {
 			abus->ahbs[i].ioarea = ioarea;
 			return i;
-		} else if ( abus->ahbs[i].ioarea == ioarea ) {
+		} else if (abus->ahbs[i].ioarea == ioarea) {
 			/* Bus already added */
 			return -1;
 		}
@@ -182,13 +169,13 @@ static int ambapp_scan2(
 
 	*root = NULL;
 
-	if ( parent ) {
+	if (parent) {
 		/* scan first bus for 64 devices, rest for 16 devices */
 		maxloops = 16;
 	}
 
 	ahbidx = ambapp_add_ahbbus(abus, ioarea);
-	if ( ahbidx < 0 ) {
+	if (ahbidx < 0) {
 		/* Bus already scanned, stop */
 		return 0;
 	}
@@ -199,20 +186,20 @@ static int ambapp_scan2(
 	ahb = (struct ambapp_pnp_ahb *) (ioarea | AMBA_CONF_AREA);
 	for (i = 0; i < maxloops; i++, ahb++) {
 		memfunc(&ahb_buf, ahb, sizeof(struct ambapp_pnp_ahb), abus);
-		if ( ahb_buf.id == 0 )
+		if (ahb_buf.id == 0)
 			continue;
 
 		/* An AHB device present here */
 		dev = ambapp_alloc_dev_struct(DEV_AHB_MST);
-		if ( !dev )
+		if (!dev)
 			return -1;
 
 		ambapp_ahb_dev_init(ioarea, abus->mmaps, &ahb_buf, dev, ahbidx);
 
-		if ( *root == NULL) 
+		if (*root == NULL)
 			*root = dev;
 
-		if ( prev != parent )
+		if (prev != parent)
 			prev->next = dev;
 		dev->prev = prev;
 		prev = dev;
@@ -223,34 +210,33 @@ static int ambapp_scan2(
 		(ioarea | AMBA_CONF_AREA | AMBA_AHB_SLAVE_CONF_AREA);
 	for (i = 0; i < maxloops; i++, ahb++) {
 		memfunc(&ahb_buf, ahb, sizeof(struct ambapp_pnp_ahb), abus);
-		if ( ahb_buf.id == 0 )
+		if (ahb_buf.id == 0)
 			continue;
 
 		/* An AHB device present here */
 		dev = ambapp_alloc_dev_struct(DEV_AHB_SLV);
-		if ( !dev )
+		if (!dev)
 			return -1;
 
 		ambapp_ahb_dev_init(ioarea, abus->mmaps, &ahb_buf, dev, ahbidx);
 
-		if ( *root == NULL)
+		if (*root == NULL)
 			*root = dev;
 
-		if ( prev != parent )
+		if (prev != parent)
 			prev->next = dev;
 		dev->prev = prev;
 		prev = dev;
 
-		ahb_info = (struct ambapp_ahb_info *)dev->devinfo;
+		ahb_info = DEV_TO_AHB(dev);
 
 		/* Is it a AHB/AHB Bridge ? */
-		if ( ((dev->device == GAISLER_AHB2AHB) &&
-		     (dev->vendor == VENDOR_GAISLER) && (ahb_info->ver>0)) ||
-		     ((dev->device == GAISLER_L2CACHE) &&
-		     (dev->vendor == VENDOR_GAISLER)) ||
-		     ((dev->device == GAISLER_GRIOMMU) &&
-		     (dev->vendor == VENDOR_GAISLER))
-		   ) {
+		if (((dev->device == GAISLER_AHB2AHB) &&
+		    (dev->vendor == VENDOR_GAISLER) && (ahb_info->ver>0)) ||
+		    ((dev->device == GAISLER_L2CACHE) &&
+		    (dev->vendor == VENDOR_GAISLER)) ||
+		    ((dev->device == GAISLER_GRIOMMU) &&
+		    (dev->vendor == VENDOR_GAISLER))) {
 			/* AHB/AHB Bridge Found, recurse down the
 			 * Bridge
 			 */
@@ -259,11 +245,11 @@ static int ambapp_scan2(
 							ahb_info->custom[1]);
 				/* Scan next bus if not already scanned */
 				if (ambapp_scan2(abus, bridge_adr, memfunc, dev,
-						&dev->children) )
+						&dev->children))
 					return -1;
 			}
-		} else if ( (dev->device == GAISLER_APBMST) &&
-		            (dev->vendor == VENDOR_GAISLER) ) {
+		} else if ((dev->device == GAISLER_APBMST) &&
+		           (dev->vendor == VENDOR_GAISLER)) {
 			/* AHB/APB Bridge Found, add the APB devices to this
 			 * AHB Slave's children
 			 */
@@ -275,16 +261,17 @@ static int ambapp_scan2(
 				(apbbase | AMBA_CONF_AREA);
 			for (j=0; j<AMBA_APB_SLAVES; j++, apb++) {
 				memfunc(&apb_buf, apb, sizeof(*apb), abus);
-				if ( apb_buf.id == 0 )
+				if (apb_buf.id == 0)
 					continue;
 
 				apbdev = ambapp_alloc_dev_struct(DEV_APB_SLV);
-				if ( !dev )
+				if (!dev)
 					return -1;
 
-				ambapp_apb_dev_init(apbbase, abus->mmaps, 								&apb_buf, apbdev, ahbidx);
+				ambapp_apb_dev_init(apbbase, abus->mmaps,
+				                    &apb_buf, apbdev, ahbidx);
 
-				if ( prevapb != dev )
+				if (prevapb != dev)
 					prevapb->next = apbdev;
 				else
 					dev->children = apbdev;
@@ -301,10 +288,7 @@ static int ambapp_scan2(
 	return 0;
 }
 
-/* Build AMBA Plug & Play device graph 
- * 
- * The root device is stored into '*root'.
- */
+/* Build AMBA Plug & Play device graph */
 int ambapp_scan(
 	struct ambapp_bus *abus,
 	unsigned int ioarea,
@@ -316,7 +300,7 @@ int ambapp_scan(
 	abus->mmaps = mmaps;
 
 	/* Default to memcpy() */
-	if ( !memfunc )
+	if (!memfunc)
 		memfunc = (ambapp_memcpy_t)memcpy;
 
 	return ambapp_scan2(abus, ioarea, memfunc, NULL, &abus->root);
@@ -325,16 +309,15 @@ int ambapp_scan(
 /* Match search options againt device */
 int ambapp_dev_match_options(struct ambapp_dev *dev, unsigned int options, int vendor, int device)
 {
-	if (	(((options & (OPTIONS_ALL_DEVS)) == OPTIONS_ALL_DEVS) ||		/* Match TYPE */
-		 ((options & OPTIONS_AHB_MSTS) && (dev->dev_type == DEV_AHB_MST)) || 
-		 ((options & OPTIONS_AHB_SLVS) && (dev->dev_type == DEV_AHB_SLV)) || 
-		 ((options & OPTIONS_APB_SLVS) && (dev->dev_type == DEV_APB_SLV))) &&
-		((vendor == -1) || (vendor == dev->vendor)) && 				/* Match ID */
-		((device == -1)  || (device == dev->device)) &&
-		(((options & OPTIONS_ALL) == OPTIONS_ALL) || 				/* Match Allocated State */
-		 ((options & OPTIONS_FREE) && DEV_IS_FREE(dev)) || 
-		 ((options & OPTIONS_ALLOCATED) && DEV_IS_ALLOCATED(dev)))
-		) {
+	if ((((options & (OPTIONS_ALL_DEVS)) == OPTIONS_ALL_DEVS) || /* TYPE */
+	    ((options & OPTIONS_AHB_MSTS) && (dev->dev_type == DEV_AHB_MST)) ||
+	    ((options & OPTIONS_AHB_SLVS) && (dev->dev_type == DEV_AHB_SLV)) ||
+	    ((options & OPTIONS_APB_SLVS) && (dev->dev_type == DEV_APB_SLV))) &&
+	    ((vendor == -1) || (vendor == dev->vendor)) && /* VENDOR/DEV ID */
+	    ((device == -1) || (device == dev->device)) &&
+	    (((options & OPTIONS_ALL) == OPTIONS_ALL) || /* Allocated State */
+	    ((options & OPTIONS_FREE) && DEV_IS_FREE(dev)) ||
+	    ((options & OPTIONS_ALLOCATED) && DEV_IS_ALLOCATED(dev)))) {
 		return 1;
 	}
 	return 0;
@@ -353,13 +336,13 @@ static int ambapp_for_each_apb(
 	struct ambapp_dev *apbslv;
 
 	ret = 0;
-	if ( dev->children && (dev->children->dev_type == DEV_APB_SLV) ) {
+	if (dev->children && (dev->children->dev_type == DEV_APB_SLV)) {
 		/* Found a APB Bridge */
 		index = 0;
 		apbslv = dev->children;
-		while(apbslv){
-			if ( ambapp_dev_match_options(apbslv, options,
-			                              vendor, device) == 1 ) {
+		while (apbslv) {
+			if (ambapp_dev_match_options(apbslv, options,
+			                             vendor, device) == 1) {
 				ret = func(apbslv, index, arg);
 				if (ret != 0)
 					break; /* Signalled stopped */
@@ -398,43 +381,43 @@ static int ambapp_for_each_dev(
 	if (options & (OPTIONS_AHB_MSTS|OPTIONS_AHB_SLVS|OPTIONS_DEPTH_FIRST)) {
 		index = 0;
 		dev = root;
-		while ( dev ) {
-			if ( (dev->dev_type == DEV_AHB_SLV) && !ahb_slave) {
+		while (dev) {
+			if ((dev->dev_type == DEV_AHB_SLV) && !ahb_slave) {
 				/* First AHB Slave */
 				ahb_slave = 1;
 				index = 0;
 			}
 
 			/* Conditions must be fullfilled for function to be
-			 * called 
+			 * called
 			 */
-			if ( ambapp_dev_match_options(dev, options, vendor,
-			                              device) == 1 ) {
+			if (ambapp_dev_match_options(dev, options, vendor,
+			                              device) == 1) {
 				/* Correct device and vendor ID */
 				ret = func(dev, index, arg);
-				if ( ret != 0 )
+				if (ret != 0)
 					return ret; /* Signalled stopped */
 			}
 
-			if ( (options & OPTIONS_DEPTH_FIRST) &&
-			     (options & OPTIONS_APB_SLVS) ) {
+			if ((options & OPTIONS_DEPTH_FIRST) &&
+			    (options & OPTIONS_APB_SLVS)) {
 				/* Check is APB bridge, and process all APB
 				 * Slaves in that case
 				 */
 				ret = ambapp_for_each_apb(dev, options, vendor,
-				                         device, func, arg);
-				if ( ret != 0 )
+				                          device, func, arg);
+				if (ret != 0)
 					return ret; /* Signalled stopped */
 			}
 
-			if ( options & OPTIONS_DEPTH_FIRST ) {
-				if ( dev->children &&
-				     (dev->children->dev_type != DEV_APB_SLV)) {
+			if (options & OPTIONS_DEPTH_FIRST) {
+				if (dev->children &&
+				    (dev->children->dev_type != DEV_APB_SLV)) {
 					/* Found AHB Bridge, recurse */
 					ret = ambapp_for_each_dev(dev->children,
 					                     options, vendor,
 					                     device, func, arg);
-					if ( ret != 0 )
+					if (ret != 0)
 						return ret;
 				}
 			}
@@ -447,29 +430,29 @@ static int ambapp_for_each_dev(
 	/* Find APB Bridges */
 	if ((options & OPTIONS_APB_SLVS) && !(options & OPTIONS_DEPTH_FIRST)) {
 		dev = root;
-		while( dev ) {
+		while (dev) {
 			/* Check is APB bridge, and process all APB Slaves in
 			 * that case
 			 */
 			ret = ambapp_for_each_apb(dev, options, vendor, device,
 			                          func, arg);
-			if ( ret != 0 )
+			if (ret != 0)
 				return ret; /* Signalled stopped */
 			dev = dev->next;
 		}
 	}
 
 	/* Find AHB Bridges */
-	if ( !(options & OPTIONS_DEPTH_FIRST) ) {
+	if (!(options & OPTIONS_DEPTH_FIRST)) {
 		dev = root;
-		while( dev ) {
-			if ( dev->children &&
-			     (dev->children->dev_type != DEV_APB_SLV) ) {
+		while (dev) {
+			if (dev->children &&
+			    (dev->children->dev_type != DEV_APB_SLV)) {
 				/* Found AHB Bridge, recurse */
 				ret = ambapp_for_each_dev(dev->children,
 				                          options, vendor,
 							  device, func, arg);
-				if ( ret != 0 )
+				if (ret != 0)
 					return ret;
 			}
 			dev = dev->next;
