@@ -63,6 +63,14 @@ extern rtems_isr_entry set_vector( rtems_isr_entry, rtems_vector_number, int );
 #define DBG(args...)
 #endif
 
+/* #define GRETH_DEBUG_MII */
+
+#ifdef GRETH_DEBUG_MII
+#define MIIDBG(args...) printk(args)
+#else
+#define MIIDBG(args...)
+#endif
+
 #ifdef CPU_U32_FIX
 extern void ipalign(struct mbuf *m);
 #endif
@@ -162,6 +170,8 @@ struct greth_softc
    
    /*Status*/
    struct phy_device_info phydev;
+   int phy_read_access;
+   int phy_write_access;
    int fd;
    int sp;
    int gb;
@@ -193,11 +203,11 @@ struct greth_softc
 int greth_process_tx_gbit(struct greth_softc *sc);
 int greth_process_tx(struct greth_softc *sc);
 
-static char *almalloc(int sz)
+static char *almalloc(int sz, int alignment)
 {
         char *tmp;
-        tmp = calloc(1,2*sz);
-        tmp = (char *) (((int)tmp+sz) & ~(sz -1));
+        tmp = calloc(1, sz + (alignment-1));
+        tmp = (char *) (((int)tmp+alignment) & ~(alignment -1));
         return(tmp);
 }
 
@@ -241,23 +251,40 @@ void greth_interrupt (void *arg)
 
 static uint32_t read_mii(struct greth_softc *sc, uint32_t phy_addr, uint32_t reg_addr)
 {
+    sc->phy_read_access++;
     while (sc->regs->mdio_ctrl & GRETH_MDIO_BUSY) {}
     sc->regs->mdio_ctrl = (phy_addr << 11) | (reg_addr << 6) | GRETH_MDIO_READ;
     while (sc->regs->mdio_ctrl & GRETH_MDIO_BUSY) {}
-    if (!(sc->regs->mdio_ctrl & GRETH_MDIO_LINKFAIL))
+    if (!(sc->regs->mdio_ctrl & GRETH_MDIO_LINKFAIL)) {
+	MIIDBG("greth%d: mii read[%d] OK to %x.%x (0x%08x,0x%08x)\n",
+                sc->minor, sc->phy_read_access, phy_addr, reg_addr,
+                sc->regs->ctrl, sc->regs->mdio_ctrl);
+
         return((sc->regs->mdio_ctrl >> 16) & 0xFFFF);
-    else {
-	printf("greth: failed to read mii\n");
-	return (0);
+    } else {
+	printf("greth%d: mii read[%d] failed to %x.%x (0x%08x,0x%08x)\n",
+                sc->minor, sc->phy_read_access, phy_addr, reg_addr,
+                sc->regs->ctrl, sc->regs->mdio_ctrl);
+	return (0xffff);
     }
 }
 
 static void write_mii(struct greth_softc *sc, uint32_t phy_addr, uint32_t reg_addr, uint32_t data)
 {
+    sc->phy_write_access++;
     while (sc->regs->mdio_ctrl & GRETH_MDIO_BUSY) {}
     sc->regs->mdio_ctrl =
      ((data & 0xFFFF) << 16) | (phy_addr << 11) | (reg_addr << 6) | GRETH_MDIO_WRITE;
     while (sc->regs->mdio_ctrl & GRETH_MDIO_BUSY) {}
+    if (!(sc->regs->mdio_ctrl & GRETH_MDIO_LINKFAIL)) {
+	MIIDBG("greth%d: mii write[%d] OK to %x.%x (0x%08x,0x%08x)\n",
+                sc->minor, sc->phy_write_access, phy_addr, reg_addr,
+                sc->regs->ctrl, sc->regs->mdio_ctrl);
+    } else {
+	printf("greth%d: mii write[%d] failed to %x.%x (0x%08x,0x%08x)\n",
+                sc->minor, sc->phy_write_access, phy_addr, reg_addr,
+                sc->regs->ctrl, sc->regs->mdio_ctrl);
+    }
 }
 
 static void print_init_info(struct greth_softc *sc) 
@@ -313,13 +340,14 @@ greth_initialize_hardware (struct greth_softc *sc)
     sc->rxInterrupts = 0;
     sc->rxPackets = 0;
 
-    regs->ctrl = 0;
     regs->ctrl = GRETH_CTRL_RST;	/* Reset ON */
-    regs->ctrl = 0;			/* Reset OFF */
-    
+    for (i = 0; i<100 && (regs->ctrl & GRETH_CTRL_RST); i++)
+        ;
+    regs->ctrl = GRETH_CTRL_DD; 	/* Reset OFF. SW do PHY Init */
+
     /* Check if mac is gbit capable*/
     sc->gbit_mac = (regs->ctrl >> 27) & 1;
-    
+
     /* Get the phy address which assumed to have been set
        correctly with the reset value in hardware*/
     if ( sc->phyaddr == -1 ) {
@@ -327,15 +355,45 @@ greth_initialize_hardware (struct greth_softc *sc)
     } else {
         phyaddr = sc->phyaddr;
     }
+    sc->phy_read_access = 0;
+    sc->phy_write_access = 0;
 
-    /* get phy control register default values */
+    /* As I understand the PHY comes back to a good default state after
+     * Power-down or Reset, so we do both just in case. Power-down bit should
+     * be cleared.
+     * Wait for old reset (if asserted by boot loader) to complete, otherwise
+     * power-down instruction might not have any effect.
+     */
+    while (read_mii(sc, phyaddr, 0) & 0x8000) {}
+    write_mii(sc, phyaddr, 0, 0x0800); /* Power-down */
+    write_mii(sc, phyaddr, 0, 0x0000); /* Power-Up */
+    write_mii(sc, phyaddr, 0, 0x8000); /* Reset */
+
+    /* We wait about 30ms */
+    rtems_task_wake_after(rtems_clock_get_ticks_per_second()/32);
+
+    /* Wait for reset to complete and get default values */
     while ((phyctrl = read_mii(sc, phyaddr, 0)) & 0x8000) {}
-    
-    /* reset PHY and wait for completion */
-    write_mii(sc, phyaddr, 0, 0x8000 | phyctrl);
 
-    while ((read_mii(sc, phyaddr, 0)) & 0x8000) {}
-    
+    /* Enable/Disable GBit auto-neg advetisement so that the link partner
+     * know that we have/haven't GBit capability. The MAC may not support
+     * Gbit even though PHY does...
+     */
+    phystatus = read_mii(sc, phyaddr, 1);
+    if (phystatus & 0x0100) {
+        tmp1 = read_mii(sc, phyaddr, 9);
+        if (sc->gbit_mac)
+            write_mii(sc, phyaddr, 9, tmp1 | 0x300);
+        else
+            write_mii(sc, phyaddr, 9, tmp1 & ~(0x300));
+    }
+
+    /* If autonegotiation implemented we start it */
+    if (phystatus & 0x0008) {
+        write_mii(sc, phyaddr, 0, phyctrl | 0x1200);
+        phyctrl = read_mii(sc, phyaddr, 0);
+    }
+
     /* Check if PHY is autoneg capable and then determine operating mode, 
        otherwise force it to 10 Mbit halfduplex */
     sc->gb = 0;
@@ -401,8 +459,8 @@ auto_neg_done:
     sc->phydev.device = 0;
     sc->phydev.rev = 0;
     phystatus = read_mii(sc, phyaddr, 1);
-    
-    /*Read out PHY info if extended registers are available */
+
+    /* Read out PHY info if extended registers are available */
     if (phystatus & 1) {  
             tmp1 = read_mii(sc, phyaddr, 2);
             tmp2 = read_mii(sc, phyaddr, 3);
@@ -412,41 +470,46 @@ auto_neg_done:
             sc->phydev.device = (tmp2 >> 4) & 0x3F;
     }
 
-    /* Force to 10 mbit half duplex if the 10/100 MAC is used with a 1000 PHY*/
-    /*check if marvell 88EE1111 PHY. Needs special reset handling */
-    if ((phystatus & 1) && (sc->phydev.vendor == 0x005043) && (sc->phydev.device == 0x0C)) {
-            if (((sc->gb) && !(sc->gbit_mac)) || !((phyctrl >> 12) & 1)) {
-                    write_mii(sc, phyaddr, 0, sc->sp << 13);
-                    write_mii(sc, phyaddr, 0, 0x8000);
-                    sc->gb = 0;
-                    sc->sp = 0;
-                    sc->fd = 0;
-            }
-    } else {
-            if (((sc->gb) && !(sc->gbit_mac))  || !((phyctrl >> 12) & 1)) {
-                    write_mii(sc, phyaddr, 0, sc->sp << 13);
-                    sc->gb = 0;
-                    sc->sp = 0;
-                    sc->fd = 0;
-            }
+    /* Force to 10 mbit half duplex if the 10/100 MAC is used with a 1000 PHY */
+    if (((sc->gb) && !(sc->gbit_mac)) || !((phyctrl >> 12) & 1)) {
+        write_mii(sc, phyaddr, 0, sc->sp << 13);
+
+        /* check if marvell 88EE1111 PHY. Needs special reset handling */
+        if ((phystatus & 1) && (sc->phydev.vendor == 0x005043) &&
+            (sc->phydev.device == 0x0C))
+            write_mii(sc, phyaddr, 0, 0x8000);
+
+        sc->gb = 0;
+        sc->sp = 0;
+        sc->fd = 0;
     }
     while ((read_mii(sc, phyaddr, 0)) & 0x8000) {}
 
-    regs->ctrl = 0;
     regs->ctrl = GRETH_CTRL_RST;	/* Reset ON */
-    regs->ctrl = 0;
+    for (i = 0; i < 100 && (regs->ctrl & GRETH_CTRL_RST); i++)
+        ;
+    regs->ctrl = GRETH_CTRL_DD;
 
-    /* Initialize rx/tx descriptor pointers */
-    sc->txdesc = (greth_rxtxdesc *) almalloc(1024);
-    sc->rxdesc = (greth_rxtxdesc *) almalloc(1024);
+    /* Initialize rx/tx descriptor table pointers. Due to alignment we 
+     * always allocate maximum table size.
+     */
+    sc->txdesc = (greth_rxtxdesc *) almalloc(0x800, 0x400);
+    sc->rxdesc = (greth_rxtxdesc *) &sc->txdesc[128];
     sc->tx_ptr = 0;
     sc->tx_dptr = 0;
     sc->tx_cnt = 0;
     sc->rx_ptr = 0;
 
-    /* Translate the base address into an address that the GRETH core can understand */
-    drvmgr_translate(sc->dev, 0, 0, (void *)sc->txdesc, (void **)&sc->txdesc_remote);
-    drvmgr_translate(sc->dev, 0, 0, (void *)sc->rxdesc, (void **)&sc->rxdesc_remote);
+    /* Translate the Descriptor DMA table base address into an address that
+     * the GRETH core can understand
+     */
+    drvmgr_translate_check(
+        sc->dev,
+        CPUMEM_TO_DMA,
+        (void *)sc->txdesc,
+        (void **)&sc->txdesc_remote,
+        0x800);
+    sc->rxdesc_remote = sc->txdesc_remote + 0x400;
     regs->txdesc = (int) sc->txdesc_remote;
     regs->rxdesc = (int) sc->rxdesc_remote;
 
@@ -455,10 +518,15 @@ auto_neg_done:
 
     for (i = 0; i < sc->txbufs; i++)
       {
-              sc->txdesc[i].ctrl = 0;
-              if (!(sc->gbit_mac)) {
-                      drvmgr_translate(sc->dev, 0, 0, (void *)malloc(GRETH_MAXBUF_LEN), (void **)&sc->txdesc[i].addr);
-              }
+        sc->txdesc[i].ctrl = 0;
+        if (!(sc->gbit_mac)) {
+            drvmgr_translate_check(
+                sc->dev, 
+                CPUMEM_TO_DMA,
+                (void *)malloc(GRETH_MAXBUF_LEN),
+                (void **)&sc->txdesc[i].addr,
+                GRETH_MAXBUF_LEN);
+        }
 #ifdef GRETH_DEBUG
               /* printf("TXBUF: %08x\n", (int) sc->txdesc[i].addr); */
 #endif
@@ -471,7 +539,12 @@ auto_neg_done:
                   m->m_data += 2;
 	  m->m_pkthdr.rcvif = &sc->arpcom.ac_if;
           sc->rxmbuf[i] = m;
-          drvmgr_translate(sc->dev, 0, 0, (void *)mtod(m, uint32_t *), (void **)&sc->rxdesc[i].addr);
+          drvmgr_translate_check(
+            sc->dev,
+            CPUMEM_TO_DMA,
+            (void *)mtod(m, uint32_t *),
+            (void **)&sc->rxdesc[i].addr,
+            GRETH_MAXBUF_LEN);
           sc->rxdesc[i].ctrl = GRETH_RXD_ENABLE | GRETH_RXD_IRQ;
 #ifdef GRETH_DEBUG
 /* 	  printf("RXBUF: %08x\n", (int) sc->rxdesc[i].addr); */
@@ -664,7 +737,12 @@ again:
                                     m->m_data += 2;
                             dp->rxmbuf[dp->rx_ptr] = m;
                             m->m_pkthdr.rcvif = ifp;
-                            drvmgr_translate(dp->dev, 0, 0, (void *)mtod (m, uint32_t *), (void **)&dp->rxdesc[dp->rx_ptr].addr);
+                            drvmgr_translate_check(
+                                dp->dev,
+                                CPUMEM_TO_DMA,
+                                (void *)mtod (m, uint32_t *),
+                                (void **)&dp->rxdesc[dp->rx_ptr].addr,
+                                GRETH_MAXBUF_LEN);
                             dp->rxPackets++;
                     }
                     if (dp->rx_ptr == dp->rxbufs - 1) {
@@ -719,7 +797,7 @@ sendpacket (struct ifnet *ifp, struct mbuf *m)
 
     len = 0;
     temp = (unsigned char *) GRETH_MEM_LOAD(&dp->txdesc[dp->tx_ptr].addr);
-    drvmgr_translate(dp->dev, 1, 1, (void *)temp, (void **)&temp);
+    drvmgr_translate(dp->dev, CPUMEM_FROM_DMA, (void *)temp, (void **)&temp);
 #ifdef GRETH_DEBUG
     printf("TXD: 0x%08x : BUF: 0x%08x\n", (int) m->m_data, (int) temp);
 #endif
@@ -833,7 +911,12 @@ sendpacket_gbit (struct ifnet *ifp, struct mbuf *m)
             printf("\n");
 #endif
             len += m->m_len;
-            drvmgr_translate(dp->dev, 0, 0, (void *)(uint32_t *)m->m_data, (void **)&dp->txdesc[dp->tx_ptr].addr);
+            drvmgr_translate_check(
+                dp->dev,
+                CPUMEM_TO_DMA,
+                (void *)(uint32_t *)m->m_data,
+                (void **)&dp->txdesc[dp->tx_ptr].addr,
+                m->m_len);
 
             /* Wrap around? */
             if (dp->tx_ptr < dp->txbufs-1) {
@@ -1038,6 +1121,7 @@ greth_init (void *arg)
 {
     struct greth_softc *sc = arg;
     struct ifnet *ifp = &sc->arpcom.ac_if;
+    char name[4] = {'E', 'T', 'H', '0'};
 
     if (sc->daemonTid == 0)
       {
@@ -1045,7 +1129,8 @@ greth_init (void *arg)
 	  /*
 	   * Start driver tasks
 	   */
-	  sc->daemonTid = rtems_bsdnet_newproc ("DCrxtx", 4096,
+	  name[3] += sc->minor;
+	  sc->daemonTid = rtems_bsdnet_newproc (name, 4096,
 						  greth_Daemon, sc);
 
 	  /*
