@@ -94,13 +94,14 @@
 struct grpci2_regs {
 	volatile unsigned int ctrl;		/* 0x00 */
 	volatile unsigned int sts_cap;		/* 0x04 */
-	int res1;				/* 0x08 */
+	volatile unsigned int ppref;		/* 0x08 */
 	volatile unsigned int io_map;		/* 0x0C */
 	volatile unsigned int dma_ctrl;		/* 0x10 */
 	volatile unsigned int dma_bdbase;	/* 0x14 */
-	int res2[2];				/* 0x18 */
+	volatile unsigned int dma_chact;	/* 0x18 */
+	int res1;				/* 0x1C */
 	volatile unsigned int bars[6];		/* 0x20 */
-	int res3[2];				/* 0x38 */
+	int res2[2];				/* 0x38 */
 	volatile unsigned int ahbmst_map[16];	/* 0x40 */
 };
 
@@ -191,11 +192,13 @@ struct grpci2_cap_first {
 	unsigned int ext2ahb_map;
 	unsigned int io_map;
 	unsigned int pcibar_size[6];
+	unsigned int ahb_pref;
 };
 #define CAP9_CTRL_OFS 0
 #define CAP9_BAR_OFS 0x4
 #define CAP9_IOMAP_OFS 0x20
 #define CAP9_BARSIZE_OFS 0x24
+#define CAP9_AHBPREF_OFS 0x3C
 
 struct grpci2_priv *grpci2priv = NULL;
 
@@ -228,6 +231,7 @@ struct grpci2_pcibar_cfg grpci2_default_bar_mapping[6] = {
 struct grpci2_priv {
 	struct drvmgr_dev	*dev;
 	struct grpci2_regs		*regs;
+	unsigned char			ver;
 	char				irq;
 	char				irq_mode; /* IRQ Mode from CAPSTS REG */
 	char				bt_enabled;
@@ -653,6 +657,10 @@ int grpci2_hw_init(struct grpci2_priv *priv)
 	if (capptr == 0)
 		return -1;
 
+	/* Limit the prefetch for GRPCI2 version 0. */
+	if (priv->ver == 0)
+		grpci2_cfg_w32(host, capptr+CAP9_AHBPREF_OFS, 0);
+
 	/* Enable/Disable Byte twisting */
 	grpci2_cfg_r32(host, capptr+CAP9_IOMAP_OFS, &io_map);
 	io_map = (io_map & ~0x1) | (priv->bt_enabled ? 1 : 0);
@@ -712,6 +720,7 @@ int grpci2_init(struct grpci2_priv *priv)
 
 	/* Found PCI core, init private structure */
 	priv->irq = apb->irq;
+	priv->ver = apb->ver;
 	priv->regs = (struct grpci2_regs *)apb->start;
 	priv->bt_enabled = DEFAULT_BT_ENABLED;
 	priv->irq_mode = (priv->regs->sts_cap & STS_IRQMODE) >> STS_IRQMODE_BIT;
