@@ -180,6 +180,7 @@ int gptimer_init1(struct drvmgr_dev *dev)
 	int i, size;
 	struct gptimer_timer *timer;
 	union drvmgr_key_value *value;
+	unsigned char irq_ack_mask;
 #if defined(LEON3) && defined(RTEMS_DRVMGR_STARTUP)
 	char timer_index[7];
 #endif
@@ -270,6 +271,16 @@ int gptimer_init1(struct drvmgr_dev *dev)
 	/* Get Frequency that the timers are operating in (after prescaler) */
 	priv->base_freq = priv->base_clk / (priv->regs->scaler_reload + 1);
 
+	/* Stop Timer and probe Pending bit. In newer hardware the
+	 * timer has pending bit is cleared by writing a one to it,
+	 * whereas older versions it is cleared with a zero.
+	 */
+	priv->regs->timer[0].ctrl = GPTIMER_CTRL_IP;
+	if ((priv->regs->timer[0].ctrl & GPTIMER_CTRL_IP) != 0)
+		irq_ack_mask = ~GPTIMER_CTRL_IP;
+	else
+		irq_ack_mask = ~0;
+
 	priv->timer_cnt = timer_cnt;
 	for (i=0; i<timer_cnt; i++) {
 		timer = &priv->timers[i];
@@ -277,16 +288,7 @@ int gptimer_init1(struct drvmgr_dev *dev)
 		timer->tindex = i + timer_start;
 		timer->tregs = &regs->timer[(int)timer->tindex];
 		timer->tdev.drv = &gptimer_tlib_drv;
-
-		/* Stop Timer and probe Pending bit. In newer hardware the
-		 * timer has pending bit is cleared by writing a one to it,
-		 * whereas older versions it is cleared with a zero.
-		 */
-		timer->tregs->ctrl = GPTIMER_CTRL_IP;
-		if ((timer->tregs->ctrl & GPTIMER_CTRL_IP) != 0)
-			timer->irq_ack_mask = ~GPTIMER_CTRL_IP;
-		else
-			timer->irq_ack_mask = ~0;
+		timer->irq_ack_mask = irq_ack_mask;
 
 		/* Register Timer at Timer Library */
 #if defined(LEON3) && defined(RTEMS_DRVMGR_STARTUP)
@@ -401,14 +403,16 @@ void gptimer_isr(void *data)
 
 	/* Check all timers for IRQ */
 	for (i=0;i<priv->timer_cnt; i++) {
-		if (gptimer_tlib_int_pend((void *)&priv->timers[i], 1)) {
-			/* IRQ Was generated by Timer and Pending flag has been
-			 * cleared. Call ISR registered
+		if (gptimer_tlib_int_pend((void *)&priv->timers[i], 0)) {
+			/* IRQ Was generated by Timer and Pending flag has *not*
+			 * yet been cleared, this is to allow ISR to look at
+			 * pending bit. Call ISR registered. Clear pending bit.
 			 */
 			if (priv->timers[i].tdev.isr_func) {
 				priv->timers[i].tdev.isr_func(
 					priv->timers[i].tdev.isr_data);
 			}
+			gptimer_tlib_int_pend((void *)&priv->timers[i], 1);
 		}
 	}
 }
