@@ -1,5 +1,5 @@
 /**
- * @file rtems/score/powerpc.h
+ * @file rtems/powerpc/powerpc.h
  */
 
 /*
@@ -38,7 +38,7 @@
  * Note:
  *      This file is included by both C and assembler code ( -DASM )
  *
- *  $Id: powerpc.h,v 1.17 2007/07/04 12:25:49 thomas Exp $
+ *  $Id$
  */
 
 
@@ -49,13 +49,19 @@
 extern "C" {
 #endif
 
-#include <rtems/score/powerpc.h>
 
-/*
- *  Define the name of the CPU family.
+/* Till S. 2008/07/10:
+ *
+ * Using the macros/definitions which depend on a preprocessor
+ * symbol defining the CPU flavor is discouraged.
+ * I recommend to not use definitions from this file and
+ * in particular - not to add more bits and pieces.
+ *
+ * Instead, try to use run-time detection (see e.g. cpuIdent.c/cpuIdent.h)
+ * of features etc.
  */
 
-#define CPU_NAME "PowerPC"
+#include <rtems/score/powerpc.h>
 
 /*
  *  This file contains the information required to build
@@ -71,12 +77,9 @@ extern "C" {
  *    + PPC_CACHE_ALIGNMENT      - 32
  *    + PPC_LOW_POWER_MODE       - PPC_LOW_POWER_MODE_NONE
  *    + PPC_HAS_EXCEPTION_PREFIX - 1
- *    + PPC_HAS_FPU              - 1
- *    + PPC_HAS_DOUBLE           - 1 if PPC_HAS_FPU, 
- *                               - 0 otherwise
  *    + PPC_USE_MULTIPLE         - 0
  */
- 
+
 /*
  *  Define the low power mode models
  *
@@ -88,12 +91,23 @@ extern "C" {
 #define PPC_LOW_POWER_MODE_NONE      0
 #define PPC_LOW_POWER_MODE_STANDARD  1
 
+/**
+ * @brief For boards with no cache set PPC_CACHE_ALIGNMENT to this value.
+ */
+#define PPC_NO_CACHE_ALIGNMENT 4
+
+/**
+ * @brief Used to define PPC_CACHE_ALIGN_POWER for boards with no cache (and
+ * PPC_NO_CACHE_ALIGNMENT defined).
+ */
+#define PPC_NO_CACHE_ALIGNMENT_POWER 2
+
 /*
  *  Figure out all CPU Model Feature Flags based upon compiler
  *  predefines.
  */
 
-#if defined(ppc403) || defined(ppc405)
+#if defined(ppc403)
 /*
  *  IBM 403
  *
@@ -101,12 +115,7 @@ extern "C" {
  *
  *  Does not have user mode.
  */
- 
-#if defined(ppc403)
-#define CPU_MODEL_NAME "PowerPC 403"
-#elif defined (ppc405)
-#define CPU_MODEL_NAME "PowerPC 405"
-#endif
+
 #define PPC_CACHE_ALIGNMENT	16
 #define PPC_HAS_RI    	        0
 #define PPC_HAS_RFCI    	1
@@ -117,19 +126,28 @@ extern "C" {
 #define PPC_HAS_EXCEPTION_PREFIX 0
 #define PPC_HAS_EVPR             1
 
+#elif defined (ppc405)
+
+#define PPC_CACHE_ALIGNMENT	32
+#define PPC_HAS_RI    	     0
+#define PPC_HAS_RFCI    	1
+#define PPC_USE_MULTIPLE	1
+#define PPC_I_CACHE		16384
+#define PPC_D_CACHE		16384		/* except GP/CR */
+#define PPC_HAS_EXCEPTION_PREFIX 0
+#define PPC_HAS_EVPR             1
+
 #elif defined(mpc555)
 
-#define CPU_MODEL_NAME  "PowerPC 555"
-
 /* Copied from mpc505 */
-#define PPC_CACHE_ALIGNMENT	16
+#define PPC_CACHE_ALIGNMENT	PPC_NO_CACHE_ALIGNMENT
 
 /* Added by querbach@realtime.bc.ca */
 #define PPC_LOW_POWER_MODE	PPC_LOW_POWER_MODE_STANDARD
 
 /* Based on comments by Sergei Organov <osv@Javad.RU> */
-#define PPC_I_CACHE        	0 
-#define PPC_D_CACHE        	0 
+#define PPC_I_CACHE        	0
+#define PPC_D_CACHE        	0
 
 #elif defined(mpc505) || defined(mpc509)
 /*
@@ -140,7 +158,7 @@ extern "C" {
 
 #define CPU_MODEL_NAME  "PowerPC 505/509"
 
-#define PPC_CACHE_ALIGNMENT     16
+#define PPC_CACHE_ALIGNMENT     PPC_NO_CACHE_ALIGNMENT
 #define PPC_I_CACHE             4096
 #define PPC_D_CACHE             0
 
@@ -150,37 +168,21 @@ extern "C" {
 /*
  *  Submitted with original port -- book checked only.
  */
- 
-#define CPU_MODEL_NAME  "PowerPC 601"
 
 #define PPC_USE_MULTIPLE	1
 #define PPC_I_CACHE		0
 #define PPC_D_CACHE		32768
 
-#elif defined(ppc602)
-/*
- *  Submitted with original port -- book checked only.
- */
- 
-#define CPU_MODEL_NAME  "PowerPC 602"
-
-#define PPC_HAS_DOUBLE		0
-#define PPC_I_CACHE		4096
-#define PPC_D_CACHE		4096
-
 #elif defined(ppc603)
 /*
  *  Submitted with original port -- book checked only.
  */
- 
-#define CPU_MODEL_NAME  "PowerPC 603"
 
 #define PPC_I_CACHE		8192
 #define PPC_D_CACHE		8192
 
 #elif defined(ppc603e)
- 
-#define CPU_MODEL_NAME  "PowerPC 603e"
+
 /*
  *  Submitted with original port.
  *
@@ -196,19 +198,15 @@ extern "C" {
 /*
  *  Submitted with original port -- book checked only.
  */
- 
-#define CPU_MODEL_NAME  "PowerPC 604"
 
 #define PPC_I_CACHE		16384
 #define PPC_D_CACHE		16384
- 
-#elif defined(mpc860)
-/* 
- *  Added by Jay Monkman (jmonkman@frasca.com) 6/28/98 
- *  with some changes by Darlene Stewart (Darlene.Stewart@iit.nrc.ca)
- */ 
-#define CPU_MODEL_NAME  "PowerPC MPC860"
 
+#elif defined(mpc860)
+/*
+ *  Added by Jay Monkman (jmonkman@frasca.com) 6/28/98
+ *  with some changes by Darlene Stewart (Darlene.Stewart@iit.nrc.ca)
+ */
 #define PPC_I_CACHE             4096
 #define PPC_D_CACHE             4096
 #define PPC_CACHE_ALIGNMENT	16
@@ -221,11 +219,9 @@ extern "C" {
 #define PPC_MSR_3		0x00000000
 
 #elif defined(mpc821)
-/* 
+/*
  *  Added by Andrew Bray <andy@chaos.org.uk> 6/April/1999
- */ 
-#define CPU_MODEL_NAME  "PowerPC MPC821"
-
+ */
 #define PPC_I_CACHE             4096
 #define PPC_D_CACHE             4096
 #define PPC_CACHE_ALIGNMENT	16
@@ -238,15 +234,11 @@ extern "C" {
 
 #elif defined(mpc750)
 
-#define CPU_MODEL_NAME  "PowerPC 750"
-
 #define PPC_I_CACHE		16384
 #define PPC_D_CACHE		16384
 
 #elif defined(mpc7400)
 
-#define CPU_MODEL_NAME  "PowerPC 7400"
-
 #define PPC_I_CACHE		32768
 #define PPC_D_CACHE		32768
 
@@ -255,8 +247,6 @@ extern "C" {
  *  Added by S.K. Feng <feng1@bnl.gov> 10/03
  */
 
-#define CPU_MODEL_NAME  "PowerPC 7455"
-
 #define PPC_CACHE_ALIGNMENT     32
 #define PPC_I_CACHE		32768
 #define PPC_D_CACHE		32768
@@ -265,67 +255,19 @@ extern "C" {
 /*
  *  Added by Andy Dachs <a.dachs@sstl.co.uk> 23/11/2000
  */
-#define CPU_MODEL_NAME  "PowerPC MPC8260"
-
 #define PPC_I_CACHE         	16384
 #define PPC_D_CACHE         	16384
 #define PPC_CACHE_ALIGNMENT	32
 #define PPC_INTERRUPT_MAX       125
 #define PPC_USE_MULTIPLE	1
+
+#elif defined(__ppc_generic)
+#define PPC_CACHE_ALIGNMENT 32
+
 #else
- 
+
 #error "Unsupported CPU Model"
- 
-#endif
 
-/*
- *  Application binary interfaces.
- *
- *  PPC_ABI MUST be defined as one of these.
- *  Only big endian is currently supported.
- */
-/*
- *  SVR4 ABI
- */
-#define PPC_ABI_SVR4		2
-/*
- *  Embedded ABI
- */
-#define PPC_ABI_EABI		3
-
-/*
- *  Default to the EABI used by current GNU tools
- */
-
-#ifndef PPC_ABI
-#define PPC_ABI PPC_ABI_EABI
-#endif
-
-#if (PPC_ABI == PPC_ABI_SVR4)
-#define PPC_STACK_ALIGNMENT	16
-#elif (PPC_ABI == PPC_ABI_EABI)
-#define PPC_STACK_ALIGNMENT	8
-#else
-#error  "PPC_ABI is not properly defined"
-#endif
-
-/*
- *  Assemblers.
- *  PPC_ASM MUST be defined as one of these.
- *
- *  PPC_ASM_ELF:   ELF assembler. Currently used for all ABIs.
- *
- *  NOTE: Only PPC_ABI_ELF is currently fully supported.
- */
-
-#define PPC_ASM_ELF   0
-
-/*
- *  Default to the assembler format used by the current GNU tools.
- */
-
-#ifndef PPC_ASM
-#define PPC_ASM PPC_ASM_ELF
 #endif
 
 /*
@@ -351,6 +293,8 @@ extern "C" {
 #define PPC_CACHE_ALIGN_POWER 4
 #elif (PPC_CACHE_ALIGNMENT == 32)
 #define PPC_CACHE_ALIGN_POWER 5
+#elif (PPC_CACHE_ALIGNMENT == PPC_NO_CACHE_ALIGNMENT)
+#define PPC_CACHE_ALIGN_POWER PPC_NO_CACHE_ALIGNMENT_POWER
 #else
 #error "Undefined power of 2 for PPC_CACHE_ALIGNMENT"
 #endif
@@ -389,36 +333,6 @@ extern "C" {
 #define PPC_LOW_POWER_MODE PPC_LOW_POWER_MODE_NONE
 #endif
 
-/*
- *  Unless specified above, assume PPC_HAS_FPU to be a synonym for _SOFT_FLOAT.
- *  FIXME: Should we tie PPC_HAS_FPU to _SOFT_FLOAT, directly 
- *     and disallow explicitly setting PPC_HAS_FPU?
- */
-
-#ifndef PPC_HAS_FPU
-#ifdef _SOFT_FLOAT
-#define PPC_HAS_FPU 0
-#else
-#define PPC_HAS_FPU 1
-#endif
-#endif
-
-/*
- *  Unless specified above, If the model has FP support, it is assumed to
- *  support doubles (8-byte floating point numbers).
- *
- *  If the model does NOT have FP support, then the model does
- *  NOT have double length FP registers. 
- */
-
-#ifndef PPC_HAS_DOUBLE
-#if (PPC_HAS_FPU)
-#define PPC_HAS_DOUBLE 1
-#else
-#define PPC_HAS_DOUBLE 0
-#endif
-#endif
-
 /*
  *  Unless specified above, then assume the model does NOT have critical
  *  interrupt support.
@@ -467,7 +381,7 @@ extern "C" {
 #define PPC_IRQ_FIRST           PPC_IRQ_SYSTEM_RESET
 
 #if defined(ppc403) || defined(ppc405)
-                                  
+
 #define PPC_IRQ_CRIT     PPC_IRQ_SYSTEM_RESET /*0x00100- Critical int. pin */
 #define PPC_IRQ_PIT      (PPC_STD_IRQ_LAST+1) /*0x01000- Pgm interval timer*/
 #define PPC_IRQ_FIT	 (PPC_STD_IRQ_LAST+2) /*0x01010- Fixed int. timer  */
@@ -494,10 +408,10 @@ extern "C" {
 
 #elif defined(ppc601)
 #define PPC_IRQ_TRACE    (PPC_STD_IRQ_LAST+1) /*0x02000-Run/Trace Exception*/
-#define PPC_IRQ_LAST     PPC_IRQ_TRACE       
+#define PPC_IRQ_LAST     PPC_IRQ_TRACE
 
 #elif defined(ppc602)
-#define PPC_IRQ_LAST     (PPC_STD_IRQ_LAST) 
+#define PPC_IRQ_LAST     (PPC_STD_IRQ_LAST)
 
 #elif defined(ppc603) || defined(ppc603e)
 #define PPC_IRQ_TRANS_MISS (PPC_STD_IRQ_LAST+1) /*0x1000-Ins Translation Miss*/
@@ -505,12 +419,12 @@ extern "C" {
 #define PPC_IRQ_DATA_STORE (PPC_STD_IRQ_LAST+3) /*0x1200-Data Store Miss     */
 #define PPC_IRQ_ADDR_BRK   (PPC_STD_IRQ_LAST+4) /*0x1300-Instruction Bkpoint */
 #define PPC_IRQ_SYS_MGT    (PPC_STD_IRQ_LAST+5) /*0x1400-System Management   */
-#define PPC_IRQ_LAST       PPC_IRQ_SYS_MGT    
+#define PPC_IRQ_LAST       PPC_IRQ_SYS_MGT
 
 #elif defined(mpc604)
 #define PPC_IRQ_ADDR_BRK (PPC_STD_IRQ_LAST+1) /*0x1300- Inst. addr break  */
 #define PPC_IRQ_SYS_MGT  (PPC_STD_IRQ_LAST+2) /*0x1400- System Management */
-#define PPC_IRQ_LAST     PPC_IRQ_SYS_MGT  
+#define PPC_IRQ_LAST     PPC_IRQ_SYS_MGT
 
 #elif defined(mpc860) || defined(mpc821)
 #define PPC_IRQ_EMULATE         (PPC_STD_IRQ_LAST+1) /*0x1000-Software emulation  */
@@ -593,14 +507,14 @@ extern "C" {
 #define PPC_IRQ_CPM_IDMA3	(PPC_STD_IRQ_LAST + 58)
 #define PPC_IRQ_CPM_IDMA4	(PPC_STD_IRQ_LAST + 59)
 #define PPC_IRQ_CPM_SDMA	(PPC_STD_IRQ_LAST + 60)
-#define PPC_IRQ_CPM_RES_A	(PPC_STD_IRQ_LAST + 61)	
+#define PPC_IRQ_CPM_RES_A	(PPC_STD_IRQ_LAST + 61)
 #define PPC_IRQ_CPM_TIMER1	(PPC_STD_IRQ_LAST + 62)
 #define PPC_IRQ_CPM_TIMER2	(PPC_STD_IRQ_LAST + 63)
 #define PPC_IRQ_CPM_TIMER3	(PPC_STD_IRQ_LAST + 64)
 #define PPC_IRQ_CPM_TIMER4	(PPC_STD_IRQ_LAST + 65)
 #define PPC_IRQ_CPM_TMCNT	(PPC_STD_IRQ_LAST + 66)
 #define PPC_IRQ_CPM_PIT		(PPC_STD_IRQ_LAST + 67)
-#define PPC_IRQ_CPM_RES_B	(PPC_STD_IRQ_LAST + 68)	
+#define PPC_IRQ_CPM_RES_B	(PPC_STD_IRQ_LAST + 68)
 #define PPC_IRQ_CPM_IRQ1	(PPC_STD_IRQ_LAST + 69)
 #define PPC_IRQ_CPM_IRQ2	(PPC_STD_IRQ_LAST + 70)
 #define PPC_IRQ_CPM_IRQ3	(PPC_STD_IRQ_LAST + 71)
@@ -706,13 +620,6 @@ extern "C" {
 
 #define PPC_MSR_DISABLE_MASK (PPC_MSR_ME|PPC_MSR_EE|PPC_MSR_CE)
 
-/*
- *  Initial value for the FPSCR register
- */
-
-#define PPC_INIT_FPSCR		0x000000f8
-
-
 #define PPC_MINIMUM_STACK_FRAME_SIZE PPC_STACK_ALIGNMENT
 
 #ifdef __cplusplus
