@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: tslp_tsk.c,v 1.6 2004/04/15 04:00:25 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -29,7 +29,7 @@
  */
 
 ER tslp_tsk(
-  TMO tmout
+  TMO tmout __attribute__((unused))
 )
 {
   return E_OK;
