@@ -1,15 +1,15 @@
 /*
- *  RTEMS Malloc Get Status Information
+ *  RTEMS Malloc Get Free Information
  *
  *
- *  COPYRIGHT (c) 1989-2000.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: mallocfreespace.c,v 1.8 2007/05/03 21:33:39 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -28,7 +28,7 @@
 #include <errno.h>
 #include <string.h>
 
-extern Heap_Control  RTEMS_Malloc_Heap;
+#include "malloc_p.h"
 
 /*
  *  Find amount of free heap remaining
@@ -38,6 +38,6 @@ size_t malloc_free_space( void )
 {
   Heap_Information info;
 
-  _Protected_heap_Get_free_information( &RTEMS_Malloc_Heap, &info );
+  _Protected_heap_Get_free_information( RTEMS_Malloc_Heap, &info );
   return (size_t) info.largest;
 }
