@@ -2,7 +2,7 @@
  * RTEMS Monitor "manager" support.
  * Used to traverse object (chain) lists and print them out.
  *
- *  $Id: mon-manager.c,v 1.11 2004/11/01 16:35:42 joel Exp $
+ *  $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,11 +45,8 @@ rtems_monitor_manager_next(
     {
         copy = (rtems_monitor_generic_t *) canonical;
         copy->id = object->id;
-		if(table->is_string)
-    	    _Objects_Copy_name_raw(object->name, &copy->name, sizeof(copy->name));
-    	else
-	        _Objects_Copy_name_raw(&object->name, &copy->name, sizeof(copy->name));
-	}
+        copy->name = object->name.name_u32;
+    }
 
 #if defined(RTEMS_MULTIPROCESSING)
 done:
