@@ -1,7 +1,11 @@
 /*
- *  $Id: getprotoby.c,v 1.4 2000/07/14 18:52:54 joel Exp $
+ *  $Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <netdb.h>
 #include <string.h>
 #include <sys/types.h>
