@@ -1,5 +1,12 @@
 /*
- *  $Id: condsignalsupp.c,v 1.3 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -27,7 +34,7 @@
 
 int _POSIX_Condition_variables_Signal_support(
   pthread_cond_t            *cond,
-  boolean                    is_broadcast
+  bool                       is_broadcast
 )
 {
   register POSIX_Condition_variables_Control *the_cond;
@@ -36,17 +43,8 @@ int _POSIX_Condition_variables_Signal_support(
 
   the_cond = _POSIX_Condition_variables_Get( cond, &location );
   switch ( location ) {
-    case OBJECTS_REMOTE:
-#if defined(RTEMS_MULTIPROCESSING)
-      _Thread_Dispatch();
-      return POSIX_MP_NOT_IMPLEMENTED();
-      return EINVAL;
-#endif
 
-    case OBJECTS_ERROR:
-      return EINVAL;
     case OBJECTS_LOCAL:
-
       do {
         the_thread = _Thread_queue_Dequeue( &the_cond->Wait_queue );
         if ( !the_thread )
@@ -56,6 +54,13 @@ int _POSIX_Condition_variables_Signal_support(
       _Thread_Enable_dispatch();
 
       return 0;
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
-  return POSIX_BOTTOM_REACHED();
+
+  return EINVAL;
 }
