@@ -1,5 +1,12 @@
 /*
- *  $Id: condwait.c,v 1.3 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -31,6 +38,6 @@ int pthread_cond_wait(
     cond,
     mutex,
     THREAD_QUEUE_WAIT_FOREVER,
-    FALSE
+    false
   );
 }
