@@ -1,5 +1,12 @@
 /*
- *  $Id: mutexgetprioceiling.c,v 1.4 2007/03/26 22:56:12 joel Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -37,18 +44,20 @@ int pthread_mutex_getprioceiling(
 
   the_mutex = _POSIX_Mutex_Get( mutex, &location );
   switch ( location ) {
-    case OBJECTS_REMOTE:
-#if defined(RTEMS_MULTIPROCESSING)
-      return POSIX_MP_NOT_IMPLEMENTED();   /* XXX feels questionable */
-#endif
-    case OBJECTS_ERROR:
-      return EINVAL;
+
     case OBJECTS_LOCAL:
       *prioceiling = _POSIX_Priority_From_core(
         the_mutex->Mutex.Attributes.priority_ceiling
       );
       _Thread_Enable_dispatch();
       return 0;
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
-  return POSIX_BOTTOM_REACHED();
+
+  return EINVAL;
 }
