@@ -1,14 +1,14 @@
 /*
  *  POSIX Spinlock Manager -- Wait at a Spinlock
  *
- *  COPYRIGHT (c) 1989-2006.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: pspintrylock.c,v 1.1 2006/11/15 14:08:49 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -47,14 +47,18 @@ int pthread_spin_trylock(
 
   the_spinlock = _POSIX_Spinlock_Get( spinlock, &location );
   switch ( location ) {
-    case OBJECTS_REMOTE:
-    case OBJECTS_ERROR:
-      return EINVAL;
 
     case OBJECTS_LOCAL:
-      status = _CORE_spinlock_Wait( &the_spinlock->Spinlock, FALSE, 0 );
+      status = _CORE_spinlock_Wait( &the_spinlock->Spinlock, false, 0 );
       _Thread_Enable_dispatch();
       return _POSIX_Spinlock_Translate_core_spinlock_return_code( status );
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
-  return POSIX_BOTTOM_REACHED();
+
+  return EINVAL;
 }
