@@ -2,14 +2,14 @@
  *  Thread Queue Handler
  *
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: threadqextract.c,v 1.5 2005/01/27 05:57:05 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -46,12 +46,13 @@ void _Thread_queue_Extract(
   Thread_Control       *the_thread
 )
 {
-  switch ( the_thread_queue->discipline ) {
-    case THREAD_QUEUE_DISCIPLINE_FIFO:
-      _Thread_queue_Extract_fifo( the_thread_queue, the_thread );
-      break;
-    case THREAD_QUEUE_DISCIPLINE_PRIORITY:
-      _Thread_queue_Extract_priority( the_thread_queue, the_thread );
-      break;
-   }
+  /*
+   * Can not use indirect function pointer here since Extract priority
+   * is a macro and the underlying methods do not have the same signature.
+   */
+  if  ( the_thread_queue->discipline == THREAD_QUEUE_DISCIPLINE_PRIORITY )
+    _Thread_queue_Extract_priority( the_thread_queue, the_thread );
+  else /* must be THREAD_QUEUE_DISCIPLINE_FIFO */
+    _Thread_queue_Extract_fifo( the_thread_queue, the_thread );
+
 }
