@@ -2,14 +2,14 @@
  *  Thread Queue Handler
  *
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: threadqtimeout.c,v 1.6 2006/11/15 14:08:49 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -39,7 +39,7 @@
 
 void _Thread_queue_Timeout(
   Objects_Id  id,
-  void       *ignored
+  void       *ignored __attribute__((unused))
 )
 {
   Thread_Control       *the_thread;
@@ -48,7 +48,9 @@ void _Thread_queue_Timeout(
   the_thread = _Thread_Get( id, &location );
   switch ( location ) {
     case OBJECTS_ERROR:
+#if defined(RTEMS_MULTIPROCESSING)
     case OBJECTS_REMOTE:  /* impossible */
+#endif
       break;
     case OBJECTS_LOCAL:
       _Thread_queue_Process_timeout( the_thread );
