@@ -52,8 +52,7 @@ int main( void )
 
 #define CONFIGURE_MAXIMUM_TASKS           1
 #define CONFIGURE_INIT_TASK_ATTRIBUTES    RTEMS_FLOATING_POINT
-
-#define CONFIGURE_APPLICATION_DISABLE_FILESYSTEM
+#define CONFIGURE_USE_DEVFS_AS_BASE_FILESYSTEM
 
 #define CONFIGURE_RTEMS_INIT_TASKS_TABLE
 
