@@ -2,17 +2,19 @@
  *  This test file is used to verify that the header files associated with
  *  invoking this function are correct.
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: signal21.c,v 1.8 2004/04/16 09:23:26 ralf Exp $
+ *  $Id$
  */
 
-#include <signal.h>
+#include <unistd.h>
+
+void test( void );
 
 void test( void )
 {
