@@ -10,27 +10,29 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: system.h,v 1.1 2004/05/10 15:59:59 ralf Exp $
+ *  $Id$
  */
 
 #include <rtems.h>
 
-/* functions */
-
-rtems_task Init(
-  rtems_task_argument argument
-);
-
 /* configuration information */
 
 #include <bsp.h> /* for device driver prototypes */
 
+/* NOTICE: the clock driver is explicitly disabled */
+#define CONFIGURE_APPLICATION_DOES_NOT_NEED_CLOCK_DRIVER
 #define CONFIGURE_APPLICATION_NEEDS_CONSOLE_DRIVER
+#define CONFIGURE_ZERO_WORKSPACE_AUTOMATICALLY TRUE
 
 #define CONFIGURE_MAXIMUM_TASKS            1
 
-#define CONFIGURE_RTEMS_INIT_TASKS_TABLE
+#define CONFIGURE_MAXIMUM_SEMAPHORES       5
 
+#define CONFIGURE_RTEMS_INIT_TASKS_TABLE
+#define CONFIGURE_INIT_TASK_STACK_SIZE    (RTEMS_MINIMUM_STACK_SIZE * 2)
+#define CONFIGURE_EXTRA_TASK_STACKS       RTEMS_MINIMUM_STACK_SIZE
+
+/* Only remove when this macro is removed from confdefs.h. It tests it. */
 #define CONFIGURE_USE_MINIIMFS_AS_BASE_FILESYSTEM
 
 #include <rtems/confdefs.h>
